XGI
===

.. image:: https://github.com/xgi-org/xgi/raw/main/logo/logo.svg
  :width: 200

XGI is a Python package for higher-order networks.

Comple\ **X** **G**\ roup **I**\ nteractions (XGI) provides an ecosystem for the
representation, manipulation, and study of the
structure, dynamics, and functions of
complex systems with group (higher-order) interactions.

Installation
------------
XGI runs on Python 3.8 or higher.

To install the latest version of XGI, run the following command::

   $ pip install xgi

To install this package locally:

-  Clone this repository
-  Navigate to the folder on your local machine
-  Run the following command::

   $ pip install -e .["all"]


Getting Started
---------------
To get started, take a look at the `tutorials <https://github.com/xgi-org/xgi/tree/main/tutorials>`_
illustrating the library's basic functionality.

Corresponding Data
------------------
A number of higher-order datasets are available in the `XGI-DATA repository <https://gitlab.com/complexgroupinteractions/xgi-data>`_ and can be easily accessed with the ``load_xgi_data()`` function.

Contributing
------------
If you want to contribute to this project, please make sure to read the
`contributing guidelines <HOW_TO_CONTRIBUTE.md>`_.
We expect respectful and kind interactions by all contributors and users
as laid out in our `code of conduct <CODE_OF_CONDUCT.md>`_.

The XGI community always welcomes contributions, no matter how small.
We're happy to help troubleshoot XGI issues you run into,
assist you if you would like to add functionality or fixes to the codebase,
or answer any questions you may have.

Some concrete ways that you can get involved:

* **Get XGI updates** by following the XGI `Twitter <https://twitter.com/xginets>`_ account, signing up for our `mailing list <http://eepurl.com/igE6ez>`_, or starring this repository.
* **Spread the word** when you use XGI by sharing with your colleagues and friends.
* **Request a new feature or report a bug** by raising a `new issue <https://github.com/xgi-org/xgi/issues/new>`_.
* **Create a Pull Request (PR)** to address an `open issue <../../issues>`_ or add a feature.
* **Join our Zulip channel** to be a part of the `daily goings-on of XGI <https://xgi.zulipchat.com/join/7agfwo7dh7jo56ppnk5kc23r/>`_.

How to Cite
-----------
We acknowledge the importance of good software to support research, and we note
that research becomes more valuable when it is communicated effectively. To
demonstrate the value of XGI, we ask that you cite XGI in your work.
Currently, the best way to cite XGI is to go to our
`repository page <https://github.com/xgi-org/xgi>`_ and
click the "cite this repository" button on the right sidebar. This will generate
a citation in your preferred format, and will also integrate well with citation managers.

License
-------
Released under the 3-Clause BSD license (see the `license file <https://github.com/xgi-org/xgi/tree/main/license.md>`_)

Copyright (C) 2021-2023 XGI Developers